@@ -1,4 +1,6 @@
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
+
 from admin_honeypot.models import LoginAttempt
 
 
@@ -16,17 +18,17 @@ class LoginAttemptAdmin(admin.ModelAdmin):
 
     def get_session_key(self, instance):
         return '<a href="?session_key=%(key)s">%(key)s</a>' % {'key': instance.session_key}
-    get_session_key.short_description = 'Session'
+    get_session_key.short_description = _('Session')
     get_session_key.allow_tags = True
 
     def get_ip_address(self, instance):
         return '<a href="?ip_address=%(ip)s">%(ip)s</a>' % {'ip': instance.ip_address}
-    get_ip_address.short_description = 'IP Address'
+    get_ip_address.short_description = _('IP Address')
     get_ip_address.allow_tags = True
 
     def get_path(self, instance):
         return '<a href="?path=%(path)s">%(path)s</a>' % {'path': instance.path}
-    get_path.short_description = 'URL'
+    get_path.short_description = _('URL')
     get_path.allow_tags = True
 
     def has_add_permission(self, request, obj=None):
